import configparser
from onebrain.utils.config import BASE_DIR
INI_FILE ="/.onebrain.ini"
ONEBRAIN = "ONEBRAIN"

def write_config(dic):
    config = configparser.ConfigParser()
    config.add_section(ONEBRAIN)
    for key in dic:
        if dic[key]:
            config.set(ONEBRAIN, key, dic[key])
    config.write(open(BASE_DIR+INI_FILE, "w"))


def read_config():
    config = configparser.ConfigParser()
    config.read(BASE_DIR+INI_FILE, encoding='utf-8')
    dic = dict(config._sections)
    return dic

class OnebrainConfig:
    def __init__(self):
        self.token = None
        self.server = None
        self.organizationId = None
        dic = read_config()
        if ONEBRAIN in dic:
          if 'token' in dic[ONEBRAIN]:
            self.token = dic[ONEBRAIN]['token']
          if 'server'in dic[ONEBRAIN]:
            self.server = dic[ONEBRAIN]['server']
          if 'organizationid' in dic[ONEBRAIN]:
             self.organizationId = dic[ONEBRAIN]['organizationid']
    def _write_config(self):
        dic = dict()
        if self.token:
          dic['token'] = self.token
        if self.server:
          dic['server'] = self.server
        if self.organizationId:
          dic['organizationid'] = self.organizationId
        write_config(dic)

    def set_token(self, token):
        self.token = token
        self._write_config()

    def get_token(self):
        return self.token

    def set_server(self, url):
        self.server = url
        self._write_config()

    def get_server(self):
        return self.server

    def set_organizationId(self, organizationId):
        self.organizationId = organizationId
        self._write_config()

    def get_organizationId(self):
        return self.organizationId

if __name__=='__main__':
    data = {
        'name': 'afas',
        'token': 'afdsafasfdsa'
    }
    write_config(data)
    dic = read_config()
    print(dic)


# FileName : YamlDemo.py
# Author   : Adil
# DateTime : 2017/12/29 12:00
# SoftWare : PyCharm

import yaml
import os

class YamlConfig():
    def load(self,filename):
        f = open(filename, 'r', encoding='utf-8')
        cont = f.read()
        x = yaml.load(cont, Loader=yaml.FullLoader)
        return x
        # print(type(x))
        # print(x)
        # print(x['EMAIL'])
        # print(type(x['EMAIL']))
        # print(x['EMAIL']['Smtp_Server'])
        # print(type(x['EMAIL']['Smtp_Server']))
        # print(x['DB'])
        # print(x['DB']['host'])
        #
        # print(x.get('DB').get('host'))
        #
        # print(type(x.get('DB')))

if __name__ == "__main__":
    yaml_config = YamlConfig()
    yaml_config.load("dataset.yaml")



# -*-encoding:utf-8-*-
import os
import json
import configparser
import sys
from onebrain.utils.requeststool import  RequestsTool
from requests_toolbelt.multipart.encoder import MultipartEncoder
from urllib3 import encode_multipart_formdata
from onebrain.utils.process import ShowProcess
from onebrain.utils.config import BASE_DIR
from onebrain.utils.configtool import OnebrainConfig

chunkSize = 5096000
ONEBRAIN = "ONEBRAIN"
ONEBRAIN_MERGE = "ONEBRAIN_MERGE"
FILE_TAG="file:"
CHUNK_TAG="chunk:"

def getUploadUrl():
    apiUrl = "/api/1/file/upload-server";
    r = RequestsTool()
    re = r.get(apiUrl)
    return re['result']
def getChunkSize():
    return chunkSize

def setChunkSize(size):
    chunkSize = size

def getFileSize(file):
    file.seek(0, os.SEEK_END)
    fileLength = file.tell()
    file.seek(0, 0)
    return fileLength

def getAllFiles(path):
    result = []  # 所有的文件
    pathLen = len(path)
    for maindir, subdir, file_name_list in os.walk(path):
        for filename in file_name_list:
            apath = os.path.join(maindir, filename)  # 合并成一个完整路径
            apath = apath[pathLen:]
            apath = apath.replace('\\', "/")
            if apath.startswith("/"):
                apath = apath[1:]
            result.append(apath)
        # for filename in subdir:
        #
        #     apath = os.path.join(maindir, filename)  # 合并成一个完整路径
        #     print("filename=" + apath)
        #     r = getAllFiles(apath)
        #     result.extend(r)
    return result

#保存进展
def saveFileProgress(id,fileName):
    file =BASE_DIR+"/"+id
    if os.path.exists(file) == False:
        with open(file, 'w') as f:
            f.writelines(FILE_TAG+fileName+"\n")
    else:
        with open(file, 'a') as f:
            f.writelines(FILE_TAG+fileName+"\n")

#保存chunk进展
def saveChunkProgress(id,chunkName):
    file =BASE_DIR+"/"+id
    if os.path.exists(file) == False:
        with open(file, 'w') as f:
            f.writelines(CHUNK_TAG+chunkName+"\n")
    else:
        with open(file, 'a') as f:
            f.writelines(CHUNK_TAG+chunkName+"\n")

def readProgress(id):
    file =BASE_DIR+"/"+id
    fileDict = {}
    chunkDict = {}
    if os.path.exists(file) == False:
        return fileDict,chunkDict
    with open(file, 'r') as f:
        line = f.readline()
        while line:
            line = line.strip('\n')
            if line.startswith(FILE_TAG):
                fileDict[line[len(FILE_TAG):]]=True
            if line.startswith(CHUNK_TAG):
                chunkDict[line[len(CHUNK_TAG):]] = True
            line = f.readline()
    return fileDict, chunkDict

def getFileName(fileFullPath):
    index = fileFullPath.rindex('\\')
    if index == -1:
        return fileFullPath
    else:
        return fileFullPath[index + 1:]

def mergeFile(fileName,type,path):
    data = {
        "uuid": path,
        "path": path,
        "type": type,
        "relativePath": fileName
    }
    rq = RequestsTool()
    url = "/api/1/file/merge"
    re = rq.post(url, data)
    if 'result' in re and re['result'] == 200:
        print(fileName + " merge success")
        return True
    else:
        print(fileName+" error")
        print(re)
        return False

def getTotalSize(path, finishFiles):
    if path.endswith("/")==False:
        path = path + "/"
    targetFiles = getAllFiles(path)
    totalSize = 0
    for item in targetFiles:
        with open(path+item, 'a') as f:
            fileSize = getFileSize(f)
            totalChunks = int(fileSize / chunkSize)
            lastSize = fileSize % chunkSize
            if lastSize != 0:
                totalChunks = totalChunks + 1
            if totalChunks == 0:
               totalChunks =1
            totalSize = totalSize + totalChunks
    return totalSize

def fileChunckUpLoad(path,apiUrl,fileName, chunkNumber, totalChunks, fileLength):
    file = open(path+fileName, "rb")
    file.seek(chunkSize*(chunkNumber-1))
    fileData = file.read(chunkSize)

    m = MultipartEncoder(
        fields={
            'chunkNumber': str(chunkNumber),
            'chunkSize': str(chunkSize),
            'currentChunkSize': str(len(fileData)),
            'totalSize': str(fileLength),
            'filename': fileName,
            'relativePath': fileName,
            'totalChunks': str(totalChunks),
            'file': ('test01.xlsx', fileData,
                                    'application/octet-stream')
        })
    rq = RequestsTool()
    re = rq.upload(apiUrl, m)
    if 'code'in re and re['code'] == 200:
        print(fileName+str(chunkNumber)+" success")
        return True
    print(fileName+str(chunkNumber)+" error")
    print(str(chunkNumber) + " error")
    print(re)
    return False

def uploadPathFiles(id,type,uuid, path,resume=True):
    if path.endswith("/") is False:
        path = path + "/"
    targetFiles = getAllFiles(path)
    finishFiles = {}
    finishChunk = {}
    url = getUploadUrl()
    of = OnebrainConfig()
    tk = of.get_organizationId()
    apiUrl = url+"?type="+type+"&uuid="+uuid+"&tenantId="+tk
    if resume:
        if os.path.exists(BASE_DIR +"/"+ id):
            finishFiles ,finishChunk = readProgress(id)
    finish = False
    finishSize = 0
    totalSize = getTotalSize(path,finishFiles)
    if totalSize == 0:
        print("没有文件需要上传")
        return
    max_steps = totalSize
    process_bar = ShowProcess(max_steps, 'OK')
    for i in range(3):
        error = False
        for item in targetFiles:
            with open(path+item, 'a') as f:
                fileSize = getFileSize(f)
                totalChunks = int(fileSize / chunkSize)
                lastSize = fileSize % chunkSize
                if lastSize != 0:
                   totalChunks = totalChunks + 1
                if totalChunks == 0:
                    totalChunks = totalChunks + 1
                if item in finishFiles.keys():
                    if i ==0:
                        finishSize = finishSize + totalChunks
                        process_bar.show_process(finishSize)
                    continue
                if totalChunks == 1 or totalChunks == 0 :
                    result = fileChunckUpLoad(path, apiUrl, item, 1, 1, fileSize)
                    if result is True:
                        finishFiles[item] = True
                        saveFileProgress(id, item)
                        finishSize = finishSize + 1
                        process_bar.show_process(finishSize)
                    else:
                        error = True
                else:
                   chunkError = False
                   for i in range(totalChunks):
                       key = item + "/" + str(i+1)
                       if key in finishChunk.keys():
                           finishSize = finishSize + 1
                           continue
                       result = fileChunckUpLoad(path,apiUrl,item,i+1,totalChunks,fileSize)
                       if result == True:
                            finishChunk[key] = True
                            saveChunkProgress(id, key)
                            finishSize = finishSize + 1
                            process_bar.show_process(finishSize)
                       else:
                           error = True
                           chunkError = True
                   if chunkError == False:
                           result = mergeFile(item,type , uuid)
                           if result == True:
                               finishFiles[item] = True
                               saveFileProgress(id, item)
                           else:
                               error = True

        if error is False:
           return

if __name__ == "__main__":
    filePath ="c:/Users/like/Downloads"
    fileName = "bs.png"
    file = open(filePath+"/"+fileName,"rb")
    fileSize = getFileSize(file)
    totalChunks = int(fileSize/chunkSize)
    if fileSize % chunkSize != 0:
        totalChunks = totalChunks+1
    apiUrl = "/api/1/file/upload?type=dataset&uuid=bfe9b8f8b3ab62ce876069fa71b1eead"
    fileChunckUpLoad(apiUrl, fileName, 1, totalChunks, fileSize)



#!/usr/bin/python3
import click
from  onebrain.utils.yamltool  import YamlConfig
from   onebrain.utils.requeststool import  RequestsTool
from onebrain.utils.configtool import OnebrainConfig
from onebrain.dataset import DataSet
@click.group()
def onebrain():
    pass

@click.command()
@click.option("-server",  prompt="server", help="the Url of onebrain server")
@click.option("-username", prompt="username",
                  help="username")
@click.option("-password", prompt="password", help="password")
def login(server, username, password):
    base_url = "/api/1/auth/cli/login"
    login_url = server + base_url
    params ={
        "password": password,
        "username": username
    }
    rq = RequestsTool()
    re = rq.post(login_url, params)
    print(re)
    if re['code'] == 200:
        print('token' + re['data']['token'])
        oc = OnebrainConfig()
        oc.set_server(server)
        oc.set_token(re['data']['token'])
    else:
        print(re['msg'])

    return

@click.command()
@click.option("-file",  prompt="filename", help="the filename of config ")
def create(file):
    yaml_config = YamlConfig()
    yaml = yaml_config.load(file)
    if 'kind' in yaml:
      if yaml['kind'].lower() == 'dataset'.lower():
         dataset = DataSet(yaml)
         dataset.create()
    return

@click.command()
@click.option("--f",  prompt="filename", help="the filename of config ")
def update(option ,filename):
    return
@click.command()
@click.option("--f",  prompt="filename", help="the filename of config ")
def delete(option ,filename):
    return
@click.command()
@click.option("-name",  prompt="name", help="the naem of dataset")
def find(name):
    dataset = DataSet()
    dataset.find(name)
onebrain.add_command(login)
onebrain.add_command(create)
onebrain.add_command(update)
onebrain.add_command(delete)
onebrain.add_command(find)
if __name__ == '__main__':
    onebrain()


from   onebrain.utils.requeststool import  RequestsTool
import onebrain.utils.FileUpload as uoLoad
class DataSet():
    def __init__(self, yaml=None):
        self.api_url ='/api/1/datasets'
        if yaml:
            metadata = yaml['metadata']
            self.name = metadata['name']
            if 'version' in metadata:
                self.version = metadata['version']
            if 'labels' in metadata:
                self.labels = metadata['labels']
            if 'description' in metadata:
                self.description = metadata['description']
            if 'filepath' in metadata:
                self.filepath = metadata['filepath']
            if 'visibility' in metadata:
                self.visibility =  metadata['visibility']

    def find(self, name,visibility):
        r = RequestsTool()
        url=self.api_url+"/byname/"+name+"/"+str(visibility)
        re = r.get(url)
        if  'status'in re and re['status'] == 200:
            return re['result']['id']
        else:
            print(re)

    def create(self):
        r = RequestsTool()
        data = {
            "name": self.name,
            "version": self.version,
            "labels": self.labels,
            "visibility": self.visibility,
            "description": self.description
        }
        re = r.post(self.api_url, data)
        print(re)
        if  'status'in re and re['status'] == 200:
            id = re['result']['id']
            self.append(id,self.filepath)

    def delete(self):
        id = self.find(self.name, self.visibility)
        if id:
            r = RequestsTool()
            url = self.api_url+"/"+id
            re = r.delete(url)
            if 'status' in re and re['status'] == 200:
               print("删除成功")
        else:
            print("没有找到数据集")
    def update(self):
        id = self.find(self.name, self.visibility)
        print(id)
        if id == None:
            print("没有找到数据集")
            return
        r = RequestsTool()
        data = {
            "id": id,
            "name": self.name,
            "version": self.version,
            "visibility": self.visibility,
            "labels": self.labels,
            "description": self.description
        }
        print(data)
        re = r.put(self.api_url, data)
        print(re)
        if 'status' in re and re['status'] == 200:
            self.append(id, self.filepath)


    def append(self, id, path):
        print(id)
        print(path)
        uoLoad.uploadPathFiles(id,"dataset",id, path)



import requests
import json
from requests_toolbelt.multipart.encoder import MultipartEncoder
from onebrain.utils.configtool import OnebrainConfig
num = 0
class RequestsTool():
    TOKEN = None
    def __init__(self, token=None ):
        self.headers = {}
        if token:
            RequestsTool.TOKEN = token
        else:
            of = OnebrainConfig()
            tk = of.get_token()
            RequestsTool.TOKEN = tk

    def set_token(self, token):
        if token:
            self.headers['authorization'] = token

    def _get_headers(self):
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/85.0.4183.121 Safari/537.36',
            'content-type': 'application/json;charset=utf-8'
        }
        if RequestsTool.TOKEN:
            headers['authorization'] = RequestsTool.TOKEN
        for (k, v) in self.headers.items():
            headers[k] = v
        return headers

    def _get_upload_headers(self,data):
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/85.0.4183.121 Safari/537.36',
            "Content-Type": data.content_type
        }
        if RequestsTool.TOKEN:
            headers['authorization'] = RequestsTool.TOKEN
        for (k, v) in self.headers.items():
            headers[k] = v
        return headers

    def _get_url(self, api):
        if api.startswith("http"):
            return api
        else:
            of = OnebrainConfig()
            server = of.get_server()
            if server == None:
                return api
            print(server)
            return server + api

    def add_header(self, key, value):
        self.headers[key] = value

    def get(self, url, params=None):
        response = requests.get(self._get_url(url) , headers=self._get_headers(), params=params)
        self._checkLogin(response.json())
        if 'Authorization' in response.headers:
            token = response.headers['Authorization']
            if token:
                oc = OnebrainConfig()
                oc.set_token(token)
        return response.json()
    

    def post(self, url, data=None):
        response = requests.post(self._get_url(url), headers=self._get_headers(), json=data)
        self._checkLogin(response.json())
        if 'Authorization' in response.headers:
            token = response.headers['Authorization']
            if token:
                oc = OnebrainConfig()
                oc.set_token(token)
        return response.json()

      

    def put(self, url, data=None):
        response = requests.put(self._get_url(url), headers=self._get_headers(), json=data)
        self._checkLogin(response.json())
        if 'Authorization' in response.headers:
            token = response.headers['Authorization']
            if token:
                oc = OnebrainConfig()
                oc.set_token(token)
        return response.json()
    def upload(self, url, data=None):
        response = requests.post(self._get_url(url), headers=self._get_upload_headers(data), data=data)
        self._checkLogin(response.json())
        global num
        num = num + 1
        if num % 100 == 0:
            num = 0
            if 'Authorization' in response.headers:
                token =response.headers['Authorization']
                if token:
                    oc = OnebrainConfig()
                    oc.set_token(token)
        return response.json()
          

    def delete(self, url):
        response = requests.delete(self._get_url(url), headers=self._get_headers())
        self._checkLogin(response.json())
        if 'Authorization' in response.headers:
            token = response.headers['Authorization']
            if token:
                oc = OnebrainConfig()
                oc.set_token(token)
        return response.json()
  

    def _checkLogin(self,re):
        if 'httpCode' in re:
            if re['httpCode'] == 401:
                  raise Exception("没有登录")        

def _test_get(token):
    r = RequestsTool(token)
    _url = " https://api.platform.baai.ac.cn/api/1/project"
    _param = {
        "current": 1,
        "size": 10
    }
    data = r.get(_url, _param)
    print(data)

def _test_post(token):
    r = RequestsTool(token)
    _url = " https://api.platform.baai.ac.cn/api/1/project"
    data = {
        "description": "test",
        "name": "test1",
        "engine": "1",
        id: "4b16c36cff93f3d3f4b71000dbd4fdd0"
    }
    re = r.post(_url, data)
    print(re)

def _test_put(token):
    r = RequestsTool(token)
    _url = " https://api.platform.baai.ac.cn/api/1/project"
    data = {
        "description": "test33333",
        "name": "test333331",
        "engine": "1",
        "id": "4b16c36cff93f3d3f4b71000dbd4fdd0"
    }
    in_json = json.dumps(data)

    re = r.put(_url, in_json)
    print(re)
def _test_delete(token):
    r = RequestsTool(token)
    _url = " https://api.platform.baai.ac.cn/api/1/project/183bc297d6dc29e598416af72459acd0"
    r.delete(_url)

if __name__ == "__main__":

    apiUrl = "/api/1/file/upload?type=dataset&uuid=bfe9b8f8b3ab62ce876069fa71b1eead"
    m = MultipartEncoder(
        fields={'filename': 'test01',
                'version': '10001',
                'file': ('test01.xlsx', 'SDSADASdas',
                                    'application/octet-stream')})


    print('aaa==='+m.content_type)
    r= RequestsTool()
    re = r.upload(apiUrl, data=m)
    print(re)




from   onebrain.utils.requeststool import  RequestsTool
import onebrain.utils.FileUpload as uoLoad
class Task():
    def __init__(self, yaml=None):
        self.api_url ='/api/1/task'
        self.name = None
        self.project_name = None
        self.image_name = None
        self.image_visibility = None
        self.image_version = None
        self.dataset_name = None
        self.dataset_visibility = None
        self.filepath = None
        self.master_product_name = None
        self.master_command = None
        self.slave_product_name = None
        self.slave_command = None
        self.slave_num = None
        if yaml:
            metadata = yaml['metadata']
            self.name = metadata['name']
            if 'project_name' in metadata:
                self.project_name = metadata['project_name']
            if 'image_name' in metadata:
                self.image_name = metadata['image_name']
            if 'image_visibility' in metadata:
                self.image_visibility = metadata['image_visibility']
            if 'image_version' in metadata:
                self.image_version = metadata['image_version']
            if 'master_product_name' in metadata:
                self.master_product_name = metadata['master_product_name']
            if 'master_command' in metadata:
                self.master_command = metadata['master_command']
            if 'slave_product_name' in metadata:
                self.slave_product_name = metadata['slave_product_name']
            if 'slave_num' in metadata:
                self.slave_num = metadata['slave_num']
            if 'slave_command' in metadata:
                self.slave_command = metadata['slave_command']
            if 'dataset_name' in metadata:
                self.dataset_name = metadata['dataset_name']
            if 'dataset_visibility' in metadata:
                self.dataset_visibility = metadata['dataset_visibility']    
            if 'filepath' in metadata:
                self.filepath = metadata['filepath']
    

    def _initData(self):
        data = {
            "name": self.name,
            "projectName": self.project_name,
            "imageName": self.image_name,
            "imageVisibility": self.image_visibility,
            "imageVersion": self.image_version,
            "datasetName": self.dataset_name,
            "datasetVisibility": self.dataset_visibility,
            "filepath": self.filepath,
            "masterProductName": self.master_product_name,
            "masterCommand": self.master_command,
            "slaveProductName": self.slave_product_name,
            "slaveCommand": self.slave_command,
            "salvePodNum": self.slave_num
        }
        return data

    def find(self, name, porject_name):
        r = RequestsTool()
        url=self.api_url+"/find/"+porject_name+"/"+name
        re = r.get(url)
        if  'status' in re and re['status'] == 200:
            return re['result']['id']
        else:
            print(re)
    
    def create(self):
        print("begin create")
        r = RequestsTool()
        data = self._initData()
        re = r.post(self.api_url+"/cli", data)
        if  'status'in re and re['status'] == 200:
            id = re['result']['id']
            self.append(id,self.filepath)
            if self._doDone(id):
                print("创建任务成功")
        else:
            print(re)

    def delete(self):
        id = self.find(self.name, self.project_name)
        if id:
            r = RequestsTool()
            url = self.api_url+"/"+id
            re = r.delete(url)
            if 'status' in re and re['status'] == 200:
               print("删除成功")
            else:
               print(re)
        else:
            print("任务没有找到")
    def update(self):
        id = self.find(self.name, self.project_name)
        print(id)
        if id == None:
            print("任务没有找到")
            return
        r = RequestsTool()
        data = self._initData()
        re = r.put(self.api_url+"/cli", data)
        if 'status' in re and re['status'] == 200:
            self.append(id, self.filepath)
            if self._doDone(id):
                print("创建任务成功")
        else:
            print(re)

    def start(self, debug = False):
        id = self.find(self.name, self.project_name)
        if id == None:
            print("任务没有找到")
            return
        r = RequestsTool()
        url = self.api_url+"/start/"+id
        if debug:
            url = self.api_url+"/debug/"+id
        print(url)
        re = r.put(url)
        if 'status' in re and re['status'] == 200:
            print(re['result']['version']+"启动成功")
        else:
            print(re)    
               

    def log(self,version,pod,current,size):
        id = self.find(self.name, self.project_name)
        if id == None:
            print("任务没有找到")
            return
        r = RequestsTool()
        data = {
            "pod": pod,
            "version": version,
            "current": current,
            "size": size
        }
        url = self.api_url+"/log/"+id
        re = r.get(url,params=data)
        if 'status' in re and re['status'] == 200:
            for log in re['result']:
                print(log)
        else:
            print(re)
    def describe(self):
        id = self.find(self.name, self.project_name)
        if id == None:
            print("任务没有找到")
            return
        r = RequestsTool()
        url = self.api_url+"/task_version/pageList/"+id
        re = r.get(url)
        if 'status' in re and re['status'] == 200:
            taskVersionList = re['result']['result']
            for taskVersion in taskVersionList:
                print(taskVersion['version']+"-------"+taskVersion['status'])
        else:
            print(re)

    def stop(self, version):
        id = self.find(self.name, self.project_name)
        if id == None:
            print("任务没有找到")
            return
        r = RequestsTool()
        url = self.api_url + "/stop/" + id+"/"+version
        re = r.put(url)
        if 'status' in re and re['status'] == 200:
            print("停止成功")
        else:
            print(re)
        
    def _doDone(self,id):
        r = RequestsTool()
        url = self.api_url+"/doDone/"+id
        re = r.put(url)
        if 'status' in re and re['status'] == 200:
           return True
        else:
           print(re)
           return False

    def append(self, id, path):
        uoLoad.uploadPathFiles(id,"task",id, path, False)
        


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/14 15:41
# @Author  : like
# @Site    :
# @File    : setup.py
# @Software: PyCharm
# @Description:

import setuptools


setuptools.setup(
    name = "casbrain_client",
    version = "0.0.52",
    author = "KeLi",
    description = "casbrain客户端",
    packages = setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    # basic stuff here
    scripts = [
        'onebrain-client'
    ],
    install_requires=[
        'click',
        'requests',
        'lxml',
        'pyyaml',
        'requests_toolbelt',
    ]

)


import base64
from Crypto.Cipher import PKCS1_v1_5 as Cipher_pksc1_v1_5
from Crypto.PublicKey import RSA

def _str2key(s):
    # 对字符串解码
    b_str = base64.b64decode(s)
    print(len(b_str))
    if len(b_str) < 162:
        return False

    hex_str = ''

    # 按位转换成16进制
    for x in b_str:
        h = hex(x)[2:]
        h = h.rjust(2, '0')
        hex_str += h

    # 找到模数和指数的开头结束位置
    m_start = 29 * 2
    e_start = 159 * 2
    m_len = 128 * 2
    e_len = 3 * 2

    modulus = hex_str[m_start:m_start + m_len]
    exponent = hex_str[e_start:e_start + e_len]
    return modulus, exponent


def rsa_encrypt(s, pubkey_str):
    '''
    rsa加密
    :param s:
    :param pubkey_str:公钥
    :return:
    '''
    key = _str2key(pubkey_str)

    modulus = int(key[0], 16)
    exponent = int(key[1], 16)
    pubkey = rsa.PublicKey(modulus, exponent)
    return base64.b64encode(rsa.encrypt(s.encode(), pubkey)).decode()
if __name__ == "__main__":
    key = "MFwwDQYJKoZIhvcNAQEBBQADSwAwSAJBANL378k3RiZHWx5AfJqdH9xRNBmD9wGD\n"+"2iRe41HdTNF8RUhNnHit5NpMNtGL0NPTSSpPjjI1kJfVorRvaQerUgkCAwEAAQ=="
    public_key = '-----BEGIN PUBLIC KEY-----\n' + key + '\n-----END PUBLIC KEY-----'
    str=rsa_encrypt("aaaa",public_key)
    print(str)


# TensorFlow and tf.keras
import tensorflow as tf
import os
from tensorflow import keras
from pathlib import Path
# Helper libraries
import numpy as np
import matplotlib.pyplot as plt
import os

# download the data
print('load data')
datapath = '/dataset/mnist.npz'
(train_images, train_labels), (test_images, test_labels) = tf.keras.datasets.mnist.load_data(datapath)

class_names = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']

train_images = train_images / 255.0
test_images = test_images / 255.0


def create_model():
    # It's necessary to give the input_shape，or it will fail when you load the model
    # The error will be like : You are trying to load the 4 layer models to the 0 layer
    model = keras.Sequential([
        keras.layers.Conv2D(32, [5, 5], activation=tf.nn.relu, input_shape=(28, 28, 1)),
        keras.layers.MaxPool2D(),
        keras.layers.Conv2D(64, [7, 7], activation=tf.nn.relu),
        keras.layers.MaxPool2D(),
        keras.layers.Flatten(),
        keras.layers.Dense(576, activation=tf.nn.relu),
        keras.layers.Dense(10, activation=tf.nn.softmax)
    ])

    model.compile(optimizer=tf.train.AdamOptimizer(),
                  loss='sparse_categorical_crossentropy',
                  metrics=['accuracy'])

    return model


# reshape the shape before using it, for that the input of cnn is 4 dimensions
train_images = np.reshape(train_images, [-1, 28, 28, 1])
test_images = np.reshape(test_images, [-1, 28, 28, 1])

# train
model = create_model()
model.fit(train_images, train_labels, epochs=4)

# save the model
my_file = Path("/model")
if not my_file.exists():
    os.mkdir("/model")

# Evaluate
test_loss, test_acc = model.evaluate(test_images, test_labels, verbose=0)
print('Test accuracy:', test_acc)
saved_model_path = "/model"
tf.keras.experimental.export_saved_model(model, saved_model_path)